@@ -20,20 +20,17 @@ where current_lang.translate means gettext.translation().gettext where
 gettext.translation() is the class-based API for gettext.
 """
 
-
 import gettext
 import os
 
+from friendly_traceback import debug_helper
+
 
 class LangState:
     def __init__(self):
-        self.translate = None
+        self._translate = lambda text: text
         self.lang = "en"
 
-    @staticmethod
-    def no_translation(text):
-        return text
-
     def install(self, lang=None):
         """Sets the language to be used for translations"""
         if lang is None:
@@ -64,22 +61,38 @@ class LangState:
                 # is not available.
             )
         self.lang = lang
-        self.translate = self.no_translation if lang == "en" else _lang.gettext
+        self._translate = _lang.gettext
+
+    def translate(self, text):
+        translation = self._translate(text)
+        if self.lang == "en":
+            return translation
+        if translation == text:  # pragma: no cover
+            debug_helper.log(f"Potentially untranslated text for {self.lang}:")
+            debug_helper.log(text)
+        return translation
 
 
 current_lang = LangState()  # noqa
 
 
+# Todo: replace localized messages about new cases by the function below
+# which will do the logging automatically.
+
+
 def please_report():
     _ = current_lang.translate
+    debug_helper.log("New case to consider.")
     return _(
-        "Please report this example to\n"
-        "https://github.com/aroberge/friendly/issues\n\n"
+        "Please report this example to "
+        "https://github.com/aroberge/friendly/issues.\n"
+        "If you are using a REPL, use `www('bug')` to do so.\n\n"
     )
 
 
 def no_information():
     _ = current_lang.translate
+    debug_helper.log("New case to consider.")
     return (
         _("No information is known about this exception.\n")
         + please_report()
@@ -90,6 +103,7 @@ def no_information():
     )
 
 
-def internal_error():
+def internal_error(e):
     _ = current_lang.translate
+    debug_helper.log("--> Internal error: " + repr(e))
     return _("Internal error for Friendly.\n") + please_report()
