@@ -11,27 +11,18 @@ from rich.panel import Panel  # noqa
 from rich.syntax import Syntax  # noqa
 from rich.text import Text  # noqa
 from rich.theme import Theme  # noqa
+from . import amical
 from . import brunante
 
 
 dark_background_theme = Theme(brunante.my_style)
-light_background_theme = Theme(
-    {
-        "markdown.h1": "bold #B22518",
-        "markdown.h2": "bold #B22518",  # Exception message; location header
-        "markdown.h3": "bold #0000cf",  # likely cause
-        "markdown.h4": "bold #CF6A4C",  # warning header
-        "markdown.link": "bold #3465a4 underline",
-        "markdown.item.bullet": "#3465a4",
-        "markdown.code": "#0000cf",
-    }
-)
+light_background_theme = Theme(amical.my_style)
 
 
 def init_console(
     style="dark", theme="brunante", color_system="auto", force_jupyter=None
 ):
-    def _patch_heading(self, console, options):  # noqa
+    def _patch_heading(self, *_args):
         """By default, all headings are centered by Rich; I prefer to have
         them left-justified, except for <h3>
         """
@@ -44,7 +35,7 @@ def init_console(
 
     Heading.__rich_console__ = _patch_heading
 
-    def _patch_code_block(self, console, options):  # noqa
+    def _patch_code_block(self, *_args):
         code = str(self.text).rstrip()
         if self.lexer_name == "default":
             self.lexer_name = "python"
@@ -56,13 +47,13 @@ def init_console(
     if style == "light":
         console = Console(
             theme=light_background_theme,
-            color_system=color_system,
+            color_system=color_system,  # noqa
             force_jupyter=force_jupyter,
         )
     else:
         console = Console(
             theme=dark_background_theme,
-            color_system=color_system,
+            color_system=color_system,  # noqa
             force_jupyter=force_jupyter,
         )
 
